==> haskell-posix-paths-0.3.0.0-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-posix-paths.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 posix-paths
version:              0.3.0.0
visibility:           public
id:                   posix-paths-0.3.0.0-1VwTsNMVc7Y4QNpZZ25IMb
key:                  posix-paths-0.3.0.0-1VwTsNMVc7Y4QNpZZ25IMb
license:              BSD-3-Clause
maintainer:           jwlato@gmail.com
synopsis:             POSIX filepath/directory functionality
description:
    This package gives access to certain POSIX-based Filepath/Directory
    services.

    The package is not supported under Windows (except under Cygwin).

category:             System
abi:                  3ce3489c07f54b8280b2f19d5164c02b
exposed:              True
exposed-modules:
    System.Posix.Directory.Foreign System.Posix.Directory.Traversals
    System.Posix.FilePath

import-dirs:          /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-posix-paths
hs-libraries:         HSposix-paths-0.3.0.0-1VwTsNMVc7Y4QNpZZ25IMb
depends:
    base-4.17.2.1 bytestring-0.11.5.3 unix-2.7.3
    unliftio-0.2.25.1-GCWK91PtajeLr5gMmt0DWz

haddock-interfaces:   /usr/share/doc/haskell-posix-paths/html/posix-paths.haddock
haddock-html:         /usr/share/doc/haskell-posix-paths/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-posix-paths-0.3.0.0-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-posix-paths.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 posix-paths
version:              0.3.0.0
visibility:           public
id:                   posix-paths-0.3.0.0-5HNsHKqSGrO7geCcDQOIeh
key:                  posix-paths-0.3.0.0-5HNsHKqSGrO7geCcDQOIeh
license:              BSD-3-Clause
maintainer:           jwlato@gmail.com
synopsis:             POSIX filepath/directory functionality
description:
    This package gives access to certain POSIX-based Filepath/Directory
    services.

    The package is not supported under Windows (except under Cygwin).

category:             System
abi:                  9e8b2f4d56cb4efc0b5192179dfab521
exposed:              True
exposed-modules:
    System.Posix.Directory.Foreign System.Posix.Directory.Traversals
    System.Posix.FilePath

import-dirs:          /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-posix-paths
hs-libraries:         HSposix-paths-0.3.0.0-5HNsHKqSGrO7geCcDQOIeh
depends:
    base-4.17.2.1 bytestring-0.11.5.3 unix-2.7.3
    unliftio-0.2.25.1-DYznH1vHiFW9UOG5RP6OX5

haddock-interfaces:   /usr/share/doc/haskell-posix-paths/html/posix-paths.haddock
haddock-html:         /usr/share/doc/haskell-posix-paths/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
